@@ -20,7 +20,7 @@ our @EXPORT = qw(
   $DRYRUN
 );
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 our $VERBOSE = 0;
 our $DRYRUN = 0;
 
@@ -47,7 +47,7 @@ sub read_configfile {
   my $configfile = $_[0];
 
 
-  if (-r $configfile) {
+  if (defined($configfile) && -r $configfile) {
     open(my $f, $configfile);
     my @desc = <$f>;
     chomp(@desc);
@@ -341,8 +341,14 @@ sub spawn_secure_copies {
         my $target = ($m eq 'localhost')? $fp : "$m:$fp";
         warn "Executing system command:\n\t$scp $scpoptions $sf $target\n" if $VERBOSE;
         unless ($DRYRUN) {
-          my $pid;
-          $pid{$m} = $pid = open(my $p, "$scp $scpoptions $sf $target 2>&1 |");
+          my $pid = open(my $p, "$scp $scpoptions $sf $target 2>&1 |");
+          if (exists $pid{$m}) {
+            push @{$pid{$m}}, $pid;
+          }
+          else {
+            $pid{$m} = [ $pid ];
+          }
+
           warn "Can't execute scp $scpoptions $sourcefile $target", next unless defined($pid);
 
           $proc{0+$p} = $m;
